@@ -1,5 +1,8 @@
 #!/usr/bin/env python
 
+# Copyright New York University and the in-toto contributors
+# SPDX-License-Identifier: Apache-2.0
+
 """
 <Program Name>
   test_in_toto_run.py
@@ -19,16 +22,12 @@
 """
 
 import os
-import sys
 import unittest
 import glob
 import tempfile
 
-# Use external backport 'mock' on versions under 3.3
-if sys.version_info >= (3, 3):
-  import unittest.mock as mock # pylint: disable=no-name-in-module,import-error
-else:
-  import mock # pylint: disable=import-error
+from pathlib import Path
+from unittest import mock
 
 from in_toto.models.metadata import Metablock
 from in_toto.in_toto_run import main as in_toto_run_main
@@ -63,7 +62,7 @@ class TestInTotoRunTool(CliTestCase, TmpDirMixin, GPGKeysMixin, GenKeysMixin):
         step_name=self.test_step, keyid=self.ed25519_key_enc_id)
 
     self.test_artifact = "test_artifact"
-    open(self.test_artifact, "w").close()
+    Path(self.test_artifact).touch()
 
   @classmethod
   def tearDownClass(self):
