@@ -1,6 +1,9 @@
 #!/usr/bin/env python
 #coding=utf-8
 
+# Copyright New York University and the in-toto contributors
+# SPDX-License-Identifier: Apache-2.0
+
 """
 <Program Name>
   test_runlib.py
@@ -42,6 +45,7 @@ import securesystemslib.formats
 import securesystemslib.exceptions
 
 from tests.common import TmpDirMixin
+from pathlib import Path
 
 
 class Test_ApplyExcludePatterns(unittest.TestCase):
@@ -121,7 +125,7 @@ class TestRecordArtifactsAsDict(unittest.TestCase, TmpDirMixin):
         "subdir/foosub2", "subdir/subsubdir/foosubsub"]
 
     for path in self.full_file_path_list:
-      with open(path, "w") as fp:
+      with open(path, "w", encoding="utf8") as fp:
         fp.write(path)
 
 
@@ -444,7 +448,7 @@ class TestRecordArtifactsAsDict(unittest.TestCase, TmpDirMixin):
 
   def test_hash_artifact_passing_algorithm(self):
     """Test _hash_artifact passing hash algorithm. """
-    self.assertTrue("sha256" in list(_hash_artifact("foo", ["sha256"]).keys()))
+    self.assertTrue("sha256" in list(_hash_artifact("foo", ["sha256"])))
 
 
 class TestLinkCmdExecTimeoutSetting(unittest.TestCase):
@@ -496,7 +500,7 @@ class TestInTotoRun(unittest.TestCase, TmpDirMixin):
     self.key_pub = import_rsa_publickey_from_file(self.key_path + ".pub")
 
     self.test_artifact = "test_artifact"
-    open(self.test_artifact, "w").close()
+    Path(self.test_artifact).touch()
 
   @classmethod
   def tearDownClass(self):
@@ -632,9 +636,7 @@ class TestInTotoRun(unittest.TestCase, TmpDirMixin):
 
   def test_nonexistent_directory(self):
     """Fail run, passed metadata_directory not exist. """
-    expected_error = IOError if sys.version_info < (3, 0) \
-        else FileNotFoundError
-    with self.assertRaises(expected_error):
+    with self.assertRaises(FileNotFoundError):
       in_toto_run(self.step_name, None, None, ["python", "--version"],
           True, self.key, metadata_directory='nonexistentDir')
 
@@ -644,9 +646,7 @@ class TestInTotoRun(unittest.TestCase, TmpDirMixin):
     os.write(fd, b"hello in-toto")
     os.close(fd)
     # Windows will raise FileNotFoundError instead of NotADirectoryError
-    expected_error = IOError if sys.version_info < (3, 0) \
-        else (NotADirectoryError, FileNotFoundError)
-    with self.assertRaises(expected_error):
+    with self.assertRaises((NotADirectoryError, FileNotFoundError)):
       in_toto_run(self.step_name, None, None, ["python", "--version"],
           True, self.key, metadata_directory=path)
     os.remove(path)
@@ -657,9 +657,7 @@ class TestInTotoRun(unittest.TestCase, TmpDirMixin):
     tmp_dir = os.path.realpath(tempfile.mkdtemp())
     # make the directory read only
     os.chmod(tmp_dir, stat.S_IREAD)
-    expected_error = IOError if sys.version_info < (3, 0) \
-        else PermissionError
-    with self.assertRaises(expected_error):
+    with self.assertRaises(PermissionError):
       in_toto_run(self.step_name, None, None, ["python", "--version"],
           True, self.key, metadata_directory=tmp_dir)
     os.rmdir(tmp_dir)
@@ -682,7 +680,7 @@ class TestInTotoRecordStart(unittest.TestCase, TmpDirMixin):
     self.link_name_unfinished = UNFINISHED_FILENAME_FORMAT.format(step_name=self.step_name, keyid=self.key["keyid"])
 
     self.test_material = "test_material"
-    open(self.test_material, "w").close()
+    Path(self.test_material).touch()
 
   @classmethod
   def tearDownClass(self):
@@ -738,7 +736,7 @@ class TestInTotoRecordStop(unittest.TestCase, TmpDirMixin):
         step_name=self.step_name, keyid=self.key["keyid"])
 
     self.test_product = "test_product"
-    open(self.test_product, "w").close()
+    Path(self.test_product).touch()
 
   @classmethod
   def tearDownClass(self):
@@ -791,7 +789,8 @@ class TestInTotoRecordStop(unittest.TestCase, TmpDirMixin):
     in_toto_record_start(self.step_name, [], self.key)
     in_toto_record_stop(self.step_name, [], self.key)
     with self.assertRaises(IOError):
-      open(self.link_name_unfinished, "r")
+      # pylint: disable-next=consider-using-with
+      open(self.link_name_unfinished, "r", encoding="utf8")
     self.assertTrue(os.path.isfile(self.link_name))
     os.remove(self.link_name)
 
@@ -800,7 +799,8 @@ class TestInTotoRecordStop(unittest.TestCase, TmpDirMixin):
     with self.assertRaises(IOError):
       in_toto_record_stop(self.step_name, [], self.key)
     with self.assertRaises(IOError):
-      open(self.link_name, "r")
+      # pylint: disable-next=consider-using-with
+      open(self.link_name, "r", encoding="utf8")
 
   def test_wrong_signature_in_unfinished_metadata(self):
     """Test record stop exits on wrong signature, no link recorded. """
@@ -813,7 +813,8 @@ class TestInTotoRecordStop(unittest.TestCase, TmpDirMixin):
     with self.assertRaises(SignatureVerificationError):
       in_toto_record_stop(self.step_name, [], self.key2)
     with self.assertRaises(IOError):
-      open(self.link_name, "r")
+      # pylint: disable-next=consider-using-with
+      open(self.link_name, "r", encoding="utf8")
     os.rename(changed_link_name, link_name)
     os.remove(self.link_name_unfinished)
 
@@ -855,9 +856,7 @@ class TestInTotoRecordStop(unittest.TestCase, TmpDirMixin):
 
   def test_nonexistent_directory(self):
     """Test record stop with nonexistent metadata directory"""
-    expected_error = IOError if sys.version_info < (3, 0) \
-        else FileNotFoundError
-    with self.assertRaises(expected_error):
+    with self.assertRaises(FileNotFoundError):
       in_toto_record_start(self.step_name, [], self.key)
       in_toto_record_stop(self.step_name, [], self.key,
           metadata_directory='nonexistentDir')
@@ -868,9 +867,7 @@ class TestInTotoRecordStop(unittest.TestCase, TmpDirMixin):
     os.write(fd, b"hello in-toto")
     os.close(fd)
     # Windows will raise FileNotFoundError instead of NotADirectoryError
-    expected_error = IOError if sys.version_info < (3, 0) \
-        else (NotADirectoryError, FileNotFoundError)
-    with self.assertRaises(expected_error):
+    with self.assertRaises((NotADirectoryError, FileNotFoundError)):
       in_toto_record_start(self.step_name, [], self.key)
       in_toto_record_stop(self.step_name, [], self.key,
           metadata_directory=path)
@@ -882,9 +879,7 @@ class TestInTotoRecordStop(unittest.TestCase, TmpDirMixin):
     tmp_dir = os.path.realpath(tempfile.mkdtemp())
     # make the directory read only
     os.chmod(tmp_dir, stat.S_IREAD)
-    expected_error = IOError if sys.version_info < (3, 0) \
-       else PermissionError
-    with self.assertRaises(expected_error):
+    with self.assertRaises(PermissionError):
       in_toto_record_start(self.step_name, [], self.key)
       in_toto_record_stop(self.step_name, [], self.key,
           metadata_directory=tmp_dir)
