@@ -1,5 +1,8 @@
 #!/usr/bin/env python
 
+# Copyright New York University and the in-toto contributors
+# SPDX-License-Identifier: Apache-2.0
+
 """
 <Program Name>
   test_verifylib.py
@@ -19,7 +22,6 @@
 """
 
 import os
-import sys
 import shutil
 import copy
 import tempfile
@@ -27,10 +29,7 @@ import unittest
 import glob
 import shlex
 
-if sys.version_info >= (3, 3):
-  from unittest.mock import patch # pylint: disable=no-name-in-module,import-error
-else:
-  from mock import patch # pylint: disable=import-error
+from unittest.mock import patch
 
 from datetime import datetime
 from dateutil.relativedelta import relativedelta
@@ -89,7 +88,7 @@ class Test_RaiseOnBadRetval(unittest.TestCase):
 
 
 class TestRunAllInspections(unittest.TestCase, TmpDirMixin):
-  """Test verifylib.run_all_inspections(layout)"""
+  """Test verifylib.run_all_inspections(layout, persist_inspection_links)"""
 
   @classmethod
   def setUpClass(self):
@@ -113,7 +112,7 @@ class TestRunAllInspections(unittest.TestCase, TmpDirMixin):
 
     # Create directory where the verification will take place
     self.set_up_test_dir()
-    with open("foo", "w") as f:
+    with open("foo", "w", encoding="utf8") as f:
       f.write("foo")
 
   @classmethod
@@ -124,11 +123,11 @@ class TestRunAllInspections(unittest.TestCase, TmpDirMixin):
     """Create new dummy test dir and set as base path, must ignore. """
     ignore_dir = os.path.realpath(tempfile.mkdtemp())
     ignore_foo = os.path.join(ignore_dir, "ignore_foo")
-    with open(ignore_foo, "w") as f:
+    with open(ignore_foo, "w", encoding="utf8") as f:
       f.write("ignore foo")
     in_toto.settings.ARTIFACT_BASE_PATH = ignore_dir
 
-    run_all_inspections(self.layout)
+    run_all_inspections(self.layout, True)
     link = Metablock.load("touch-bar.link")
     self.assertListEqual(list(link.signed.materials.keys()), ["foo"])
     self.assertListEqual(sorted(list(link.signed.products.keys())), sorted(["foo", "bar"]))
@@ -147,7 +146,18 @@ class TestRunAllInspections(unittest.TestCase, TmpDirMixin):
         }]
     })
     with self.assertRaises(BadReturnValueError):
-      run_all_inspections(layout)
+      run_all_inspections(layout, True)
+
+  def test_inspection_persistence_false(self):
+    """Test metadata link file non-persistence"""
+    if os.path.exists("touch-bar.link"):
+      os.remove("touch-bar.link")
+    run_all_inspections(self.layout, False)
+    self.assertFalse(os.path.exists("touch-bar.link"))
+
+  def test_inspeciton_persistence_true(self):
+    run_all_inspections(self.layout, True)
+    self.assertTrue(os.path.exists("touch-bar.link"))
 
 
 class TestVerifyCommandAlignment(unittest.TestCase):
@@ -386,15 +396,22 @@ class TestVerifyMatchRule(unittest.TestCase):
       "foo": {"sha256": self.sha256_foo},
       "foobar": {"sha256": self.sha256_foobar},
       "sub/foo": {"sha256": self.sha256_foo},
-      "sub/foobar": {"sha256": self.sha256_foobar}
-
+      "sub/foobar": {"sha256": self.sha256_foobar},
+      "lib/foo": {"sha256": self.sha256_foo},
+      "lib/foobar": {"sha256": self.sha256_foobar},
+      "lib/build/foo": {"sha256": self.sha256_foo},
+      "lib/build/foobar": {"sha256": self.sha256_foobar},
     }
     self.products = {
       "bar": {"sha256": self.sha256_bar},
       "barfoo": {"sha256": self.sha256_barfoo},
       "sub/bar": {"sha256": self.sha256_bar},
       "sub/barfoo": {"sha256": self.sha256_barfoo},
-      }
+      "sub/lib/bar": {"sha256": self.sha256_bar},
+      "sub/lib/barfoo": {"sha256": self.sha256_barfoo},
+      "build/bar": {"sha256": self.sha256_bar},
+      "build/barfoo": {"sha256": self.sha256_barfoo},
+    }
 
     self.links = {
         "dest-item": Metablock(signed=Link(
@@ -503,6 +520,61 @@ class TestVerifyMatchRule(unittest.TestCase):
         "MATCH foo WITH MATERIALS FROM dest-item-missing-link",
         set(self.materials.keys()), self.materials,
         set()
+      ],
+      [
+        # Ensures the sub/bar file matches the product file in the sub folder
+        # from the dest-item step.
+        "MATCH bar IN sub WITH PRODUCTS IN sub FROM dest-item",
+        set(self.products.keys()), self.products,
+        {"sub/bar", "sub/bar"}
+      ],
+      [
+        # Ensures the sub/bar and sub/barfoo files matches the product
+        # files in the sub folder from the dest-item step.
+        "MATCH bar* IN sub WITH PRODUCTS IN sub/ FROM dest-item",
+        set(self.products.keys()), self.products,
+        {"sub/bar", "sub/barfoo"}
+      ],
+      [
+        # Ensure the sub/bar file matches the product file in the
+        # sub/lib folder from the dest-item step.
+        "MATCH bar IN sub WITH PRODUCTS IN sub/lib FROM dest-item",
+        set(self.products.keys()), self.products,
+        {"sub/bar"}
+      ],
+      [
+        # Do not consume. Missing link
+        "MATCH bar IN sub WITH PRODUCTS IN sub FROM dest-item-missing-link",
+        set(self.products.keys()), self.products,
+        set()
+      ],
+      [
+        # Ensures the sub/foo file matches the material file in the
+        # lib folder from the dest-item step.
+        "MATCH foo IN sub WITH MATERIALS IN lib FROM dest-item",
+        set(self.materials.keys()), self.materials,
+        {"sub/foo"}
+      ],
+      [
+        # Ensures any sub/foo and sub/foobar files matches material
+        # files in the lib folder from the dest-item step.
+        "MATCH foo* IN sub WITH MATERIALS IN lib/ FROM dest-item",
+        set(self.materials.keys()), self.materials,
+        {"sub/foo", "sub/foobar"}
+      ],
+      [
+        # Ensures the sub/foo file matches the material files in the lib/build
+        # the lib/build folder from the dest-item step.
+        "MATCH foo IN sub WITH MATERIALS IN lib/build FROM dest-item",
+        set(self.materials.keys()), self.materials,
+        {"sub/foo"}
+      ],
+      [
+        # Ensures the sub/foo and sub/foobar files matches the material files
+        # in the lib/build folder from the dest-item step.
+        "MATCH foo* IN sub WITH MATERIALS IN lib/build FROM dest-item",
+        set(self.materials.keys()), self.materials,
+        {"sub/foo", "sub/foobar"}
       ]
     ]
 
